==> jc-1.4.0.tar.gz: javax/swing/text/PasswordView.h <==
// public class javax.swing.text.PasswordView

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 24019b080bec3e58 javax_swing_text_FieldView
// @dep_class 131637c86f715868 javax_swing_text_PasswordView
// @dep_class a007d47a1e2f730a javax_swing_text_PlainView
// @dep_class b564f56d2f2041c1 javax_swing_text_View

// header file dependencies
// @dep_header javax_swing_text_FieldView

#include "javax/swing/text/FieldView.h"

#ifndef _JC_javax_swing_text_PasswordView_H_
#define _JC_javax_swing_text_PasswordView_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_Element$object;

// Typedefs
typedef struct _jc_javax_swing_text_PasswordView$sub_refs	_jc_javax_swing_text_PasswordView$sub_refs;
typedef struct _jc_javax_swing_text_PasswordView$sub_nonrefs	_jc_javax_swing_text_PasswordView$sub_nonrefs;
typedef struct _jc_javax_swing_text_PasswordView$refs	_jc_javax_swing_text_PasswordView$refs;
typedef struct _jc_javax_swing_text_PasswordView$nonrefs	_jc_javax_swing_text_PasswordView$nonrefs;
typedef struct _jc_javax_swing_text_PasswordView$object	_jc_javax_swing_text_PasswordView$object;

typedef const struct _jc_javax_swing_text_PasswordView$vmethods	_jc_javax_swing_text_PasswordView$vmethods;
typedef const struct _jc_javax_swing_text_PasswordView$vtable	_jc_javax_swing_text_PasswordView$vtable;
typedef const struct _jc_javax_swing_text_PasswordView$vtype	_jc_javax_swing_text_PasswordView$vtype;

// Constructors
extern void _jc_javax_swing_text_PasswordView$method$_init$102e066f5c45b34f(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *, struct _jc_object *);

// Virtual methods
extern jint _jc_javax_swing_text_PasswordView$method$drawEchoCharacter$7137a00d3aadb38c(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jchar);
extern jint _jc_javax_swing_text_PasswordView$method$drawSelectedText$87694f227773606a(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
extern jint _jc_javax_swing_text_PasswordView$method$drawUnselectedText$44f135ebabecfc97(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
extern jchar _jc_javax_swing_text_PasswordView$method$getEchoChar$f136887932414498(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *);
extern void _jc_javax_swing_text_PasswordView$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_PasswordView$method_info$drawEchoCharacter$7137a00d3aadb38c;
extern _jc_method _jc_javax_swing_text_PasswordView$method_info$drawSelectedText$87694f227773606a;
extern _jc_method _jc_javax_swing_text_PasswordView$method_info$drawUnselectedText$44f135ebabecfc97;
extern _jc_method _jc_javax_swing_text_PasswordView$method_info$getEchoChar$f136887932414498;
extern _jc_method _jc_javax_swing_text_PasswordView$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_text_PasswordView$vmethods {
	jint	(*drawEchoCharacter$7137a00d3aadb38c)(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jchar);
	jint	(*drawSelectedText$87694f227773606a)(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
	jint	(*drawUnselectedText$44f135ebabecfc97)(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
	jchar	(*getEchoChar$f136887932414498)(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *);
};

// Vtable
struct _jc_javax_swing_text_PasswordView$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_View$vmethods	javax_swing_text_View;
	_jc_javax_swing_text_PlainView$vmethods	javax_swing_text_PlainView;
	_jc_javax_swing_text_FieldView$vmethods	javax_swing_text_FieldView;
	_jc_javax_swing_text_PasswordView$vmethods	javax_swing_text_PasswordView;
};

// Vtype
struct _jc_javax_swing_text_PasswordView$vtype {
	_jc_type			type;
	_jc_javax_swing_text_PasswordView$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_PasswordView$sub_refs {
	_jc_char_array	*oneCharBuffer;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_PasswordView$refs {
    _jc_javax_swing_text_PasswordView$sub_refs	javax_swing_text_PasswordView;
    _jc_javax_swing_text_FieldView$sub_refs	javax_swing_text_FieldView;
    _jc_javax_swing_text_PlainView$sub_refs	javax_swing_text_PlainView;
    _jc_javax_swing_text_View$sub_refs	javax_swing_text_View;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_PasswordView$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_PasswordView$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_View$sub_nonrefs	javax_swing_text_View;
    _jc_javax_swing_text_PlainView$sub_nonrefs	javax_swing_text_PlainView;
    _jc_javax_swing_text_FieldView$sub_nonrefs	javax_swing_text_FieldView;
    _jc_javax_swing_text_PasswordView$sub_nonrefs	javax_swing_text_PasswordView;
};

// Object instance structure
struct _jc_javax_swing_text_PasswordView$object {
	_jc_javax_swing_text_PasswordView$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_PasswordView$vtype	*vtype;
	_jc_javax_swing_text_PasswordView$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_PasswordView$vtype _jc_javax_swing_text_PasswordView$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_PasswordView, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_PasswordView$class_object;

#endif	/* _JC_javax_swing_text_PasswordView_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/PasswordView.h <==
// public class javax.swing.text.PasswordView

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 24019b080bec3e58 javax_swing_text_FieldView
// @dep_class 131637c86f715868 javax_swing_text_PasswordView
// @dep_class a007d47a1e2f730a javax_swing_text_PlainView
// @dep_class b564f56d2f2041c1 javax_swing_text_View

// header file dependencies
// @dep_header javax_swing_text_FieldView

#include "javax/swing/text/FieldView.h"

#ifndef _JC_javax_swing_text_PasswordView_H_
#define _JC_javax_swing_text_PasswordView_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_Element$object;

// Typedefs
typedef struct _jc_javax_swing_text_PasswordView$sub_refs	_jc_javax_swing_text_PasswordView$sub_refs;
typedef struct _jc_javax_swing_text_PasswordView$sub_nonrefs	_jc_javax_swing_text_PasswordView$sub_nonrefs;
typedef struct _jc_javax_swing_text_PasswordView$refs	_jc_javax_swing_text_PasswordView$refs;
typedef struct _jc_javax_swing_text_PasswordView$nonrefs	_jc_javax_swing_text_PasswordView$nonrefs;
typedef struct _jc_javax_swing_text_PasswordView$object	_jc_javax_swing_text_PasswordView$object;

typedef const struct _jc_javax_swing_text_PasswordView$vmethods	_jc_javax_swing_text_PasswordView$vmethods;
typedef const struct _jc_javax_swing_text_PasswordView$vtable	_jc_javax_swing_text_PasswordView$vtable;
typedef const struct _jc_javax_swing_text_PasswordView$vtype	_jc_javax_swing_text_PasswordView$vtype;

// Constructors
extern void _jc_javax_swing_text_PasswordView$method$_init$102e066f5c45b34f(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_text_PasswordView$method$drawEchoCharacter$7137a00d3aadb38c(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jchar) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_PasswordView$method$drawSelectedText$87694f227773606a(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_PasswordView$method$drawUnselectedText$44f135ebabecfc97(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
extern jchar _jc_javax_swing_text_PasswordView$method$getEchoChar$f136887932414498(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_PasswordView$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_PasswordView$method_info$drawEchoCharacter$7137a00d3aadb38c;
extern _jc_method _jc_javax_swing_text_PasswordView$method_info$drawSelectedText$87694f227773606a;
extern _jc_method _jc_javax_swing_text_PasswordView$method_info$drawUnselectedText$44f135ebabecfc97;
extern _jc_method _jc_javax_swing_text_PasswordView$method_info$getEchoChar$f136887932414498;
extern _jc_method _jc_javax_swing_text_PasswordView$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_text_PasswordView$vmethods {
	jint	(*drawEchoCharacter$7137a00d3aadb38c)(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jchar) _JC_JCNI_ATTR;
	jint	(*drawSelectedText$87694f227773606a)(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
	jint	(*drawUnselectedText$44f135ebabecfc97)(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
	jchar	(*getEchoChar$f136887932414498)(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_text_PasswordView$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_PasswordView$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_View$vmethods	javax_swing_text_View;
	_jc_javax_swing_text_PlainView$vmethods	javax_swing_text_PlainView;
	_jc_javax_swing_text_FieldView$vmethods	javax_swing_text_FieldView;
	_jc_javax_swing_text_PasswordView$vmethods	javax_swing_text_PasswordView;
};

// Vtype
struct _jc_javax_swing_text_PasswordView$vtype {
	_jc_type			type;
	_jc_javax_swing_text_PasswordView$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_PasswordView$sub_refs {
	_jc_char_array	*oneCharBuffer;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_PasswordView$refs {
    _jc_javax_swing_text_PasswordView$sub_refs	javax_swing_text_PasswordView;
    _jc_javax_swing_text_FieldView$sub_refs	javax_swing_text_FieldView;
    _jc_javax_swing_text_PlainView$sub_refs	javax_swing_text_PlainView;
    _jc_javax_swing_text_View$sub_refs	javax_swing_text_View;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_PasswordView$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_PasswordView$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_View$sub_nonrefs	javax_swing_text_View;
    _jc_javax_swing_text_PlainView$sub_nonrefs	javax_swing_text_PlainView;
    _jc_javax_swing_text_FieldView$sub_nonrefs	javax_swing_text_FieldView;
    _jc_javax_swing_text_PasswordView$sub_nonrefs	javax_swing_text_PasswordView;
};

// Object instance structure
struct _jc_javax_swing_text_PasswordView$object {
	_jc_javax_swing_text_PasswordView$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_PasswordView$vtype	*vtype;
	_jc_javax_swing_text_PasswordView$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_PasswordView$vtype _jc_javax_swing_text_PasswordView$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_PasswordView, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_PasswordView$class_object;

#endif	/* _JC_javax_swing_text_PasswordView_H_ */
